==> xlang-0.7.0.tar.gz: xlang-0.7.0/src/xlang/langlisp_yacc.h <==
/* A Bison parser, made by GNU Bison 1.875b.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     IF = 258,
     ELSE = 259,
     CLASS = 260,
     RETURN = 261,
     WHILE = 262,
     DYNAMIC = 263,
     STATIC = 264,
     V_TRUE = 265,
     V_FALSE = 266,
     V_NULL = 267,
     GLOBAL = 268,
     FNCT = 269,
     LOCAL = 270,
     VOID = 271,
     CHAR = 272,
     UCHAR = 273,
     SHORT = 274,
     USHORT = 275,
     INT = 276,
     UINT = 277,
     FLOAT = 278,
     DOUBLE = 279,
     STRING = 280,
     BOOL = 281,
     IDENTIFIER = 282,
     V_INT = 283,
     V_FLOAT = 284,
     V_STRING = 285
   };
#endif
#define IF 258
#define ELSE 259
#define CLASS 260
#define RETURN 261
#define WHILE 262
#define DYNAMIC 263
#define STATIC 264
#define V_TRUE 265
#define V_FALSE 266
#define V_NULL 267
#define GLOBAL 268
#define FNCT 269
#define LOCAL 270
#define VOID 271
#define CHAR 272
#define UCHAR 273
#define SHORT 274
#define USHORT 275
#define INT 276
#define UINT 277
#define FLOAT 278
#define DOUBLE 279
#define STRING 280
#define BOOL 281
#define IDENTIFIER 282
#define V_INT 283
#define V_FLOAT 284
#define V_STRING 285




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 58 "langlisp_yacc.y"
typedef union YYSTYPE {
  XLExpr*     expr;
  XLTypeType  xtype;
  xdouble     val_float;
  xint        val_int;
  xchar       val_string[100];
  xchar       identifier[100];
} YYSTYPE;
/* Line 1252 of yacc.c.  */
#line 106 "langlisp_yacc.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE lisp_lval;

==> xlang-0.7.4.tar.gz: xlang-0.7.4/src/xlang/langlisp_yacc.h <==
/* A Bison parser, made by GNU Bison 1.875b.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     IF = 258,
     ELSE = 259,
     CLASS = 260,
     RETURN = 261,
     WHILE = 262,
     DYNAMIC = 263,
     STATIC = 264,
     V_TRUE = 265,
     V_FALSE = 266,
     V_NULL = 267,
     GLOBAL = 268,
     FNCT = 269,
     LOCAL = 270,
     VOID = 271,
     CHAR = 272,
     UCHAR = 273,
     SHORT = 274,
     USHORT = 275,
     INT = 276,
     UINT = 277,
     FLOAT = 278,
     DOUBLE = 279,
     STRING = 280,
     BOOL = 281,
     IDENTIFIER = 282,
     V_INT = 283,
     V_FLOAT = 284,
     V_STRING = 285
   };
#endif
#define IF 258
#define ELSE 259
#define CLASS 260
#define RETURN 261
#define WHILE 262
#define DYNAMIC 263
#define STATIC 264
#define V_TRUE 265
#define V_FALSE 266
#define V_NULL 267
#define GLOBAL 268
#define FNCT 269
#define LOCAL 270
#define VOID 271
#define CHAR 272
#define UCHAR 273
#define SHORT 274
#define USHORT 275
#define INT 276
#define UINT 277
#define FLOAT 278
#define DOUBLE 279
#define STRING 280
#define BOOL 281
#define IDENTIFIER 282
#define V_INT 283
#define V_FLOAT 284
#define V_STRING 285




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
#line 58 "parser/lisplike/langlisp_yacc.y"
typedef union YYSTYPE {
  XLExpr*     expr;
  XLTypeType  xtype;
  xdouble     val_float;
  xint        val_int;
  xchar       val_string[100];
  xchar       identifier[100];
} YYSTYPE;
/* Line 1252 of yacc.c.  */
#line 106 "langlisp_yacc.h"
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

extern YYSTYPE lisp_lval;
